@@ -75,8 +75,12 @@ LockScreen::LockScreen()
     QString orientation = QSettings().value("Main/Orientation", "Auto").toString().toLower();
     if (orientation == "landscape"){
         m_View->setAttribute(Qt::WA_Maemo5LandscapeOrientation);
+        m_WasPortrait = false;
+        LsWidget::setPortrait(false);
     } else if (orientation == "portrait"){
         m_View->setAttribute(Qt::WA_Maemo5PortraitOrientation);        
+        m_WasPortrait = true;
+        LsWidget::setPortrait(true);
     }else{
         m_View->setAttribute(Qt::WA_Maemo5AutoOrientation);
         conn.connect("",
@@ -345,9 +349,11 @@ void LockScreen::setSizeAndPosition()
 
         foreach(QGraphicsItem* item, m_Scene.items()){
             LsWidget* w = dynamic_cast<LsWidget*>(item);
-            if (w != NULL)
+            if (w != NULL){
+                w->onOrientationChanged();
                 w->setSizeAndPosition(QSize(w->size().width(), w->size().height()),
                                       QPoint(w->pos().x(), w->pos().y()));
+            }
         }
         m_View->update();
     }
