@@ -73,13 +73,16 @@ int main(int argc, char *argv[])
     if (!QFile().exists(name))
         QFile().copy(":/DefaultSettings.conf", name);
 
+    //Translation:
     QString locale = QLocale::system().name();
     qDebug() << "Locale:" << locale;
     QTranslator translator;
-    if (translator.load(QString(":/qtlockscreen_%1").arg(locale)))
+    if (translator.load(QString("/opt/qtlockscreen/qtlockscreen_%1").arg(locale)))
         a.installTranslator(&translator);
 
     qDebug() << a.applicationName() << a.applicationVersion();
+    qDebug() << "Copyright  2011 Paolo Iommarini";
+    qDebug() << "sakya_tg@yahoo.it";
     LockScreen l;
 
     if (LockScreen::Debug || LockScreen::isLocked())
