@@ -32,9 +32,12 @@ public:
     void applySettings();
 
 private:
+    bool m_IsCharging;
     float m_Percentage;
     QList<QPixmap> m_Images;
+    QPixmap m_ChargingImage;
     QFont m_PercFont;
+    QColor m_PercColor;
 
 private slots:
 #ifdef Q_WS_MAEMO_5
